bbprep.Process
==============

.. currentmodule:: bbprep

.. autoclass:: Process
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~Process.calculate_score
      ~Process.get_all_scores
      ~Process.get_data
      ~Process.get_minimum
      ~Process.get_minimum_id
   
   

   
   
   